package com.lyg.tools.config.cors;

import lombok.Data;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;

import javax.servlet.*;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

@Data
@WebFilter(filterName = "CorsFilter ")
@Configuration
@ConfigurationProperties(prefix = "cors")
public class CorsFilter implements Filter {

    Boolean enabled;
    List<String> methods;
    List<String> headers;

    // 必须要带有 return
    // 不然返回数据会变多
    @Override
    public void doFilter(ServletRequest req, ServletResponse res, FilterChain chain) throws IOException, ServletException {
        if (null == enabled || !enabled) {
            chain.doFilter(req, res);
            return;
        }

        HttpServletResponse response = (HttpServletResponse) res;
        HttpServletRequest request = (HttpServletRequest) req;

        String reqHeaders = request.getHeader("Access-Control-Request-Headers");
        if (null == reqHeaders || "".equals(reqHeaders.trim())) {
            reqHeaders = String.join(",", headers);
        }

        response.setHeader("Access-Control-Allow-Origin", request.getHeader("Origin"));
        response.setHeader("Access-Control-Allow-Methods", String.join(",", methods));
        response.setHeader("Access-Control-Allow-Headers", reqHeaders);
        response.setHeader("Access-Control-Allow-Credentials", "true");
        response.setHeader("Access-Control-Max-Age", "3600");

        // 如果是OPTIONS则结束请求
        if (HttpMethod.OPTIONS.toString().equals(request.getMethod())) {
            response.setStatus(HttpStatus.NO_CONTENT.value());
        }

        chain.doFilter(req, res);
        return;
    }
}
