package com.lyg.tools.controller;

import com.lyg.tools.common.FileUtil;
import com.lyg.tools.common.ResponseBean;
import com.lyg.tools.common.StringUtil;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

@Api(tags = "文件上传")
@RestController
@RequestMapping("/")
public class UploadController {

    @Autowired
    FileUtil fileUtil;

    public static String getFileType(MultipartFile file) throws Exception {
        String fileName = file.getOriginalFilename();
        // 通过文件名获取文件后缀，并与MIME类型映射表对比获取文件类型
        String fileSuffix = fileName.substring(fileName.lastIndexOf(".") + 1);
        // 这里可以扩展为查询MIME类型映射表
        return fileSuffix;
    }

    /**
     * 通用端上传文件
     *
     * @return
     * @throws Exception
     */
    @PostMapping("/upload/cms")
    public ResponseBean uploadAdmin(@RequestParam(value = "file") MultipartFile file,
                                    @PathVariable(value = "appid") String appid
    ) throws Exception {
        String fileType = getFileType(file);

        Map<String, Object> res = new HashMap<>();
        String fileName = file.getOriginalFilename();
        String path = fileUtil.saveFile(file, appid);
        res.put("attachUrl", path);
        res.put("attachName", fileName);
        res.put("fileType", fileType);
        return ResponseBean.success(res);
    }

    /**
     * 通过 Base64 上传文件
     *
     * @param appid 应用Id
     * @return
     * @throws Exception
     */
    @PostMapping("/upload/base64/{appid}")
    public ResponseBean uploadBase64(
            @PathVariable(value = "appid") String appid,
            @RequestParam(value = "base64") String base64,
            @RequestParam(value = "fileName", defaultValue = "unknown.jpg") String fileName
    ) throws Exception {

        Map<String, Object> res = new HashMap<>();
        byte[] bytes = StringUtil.base64ToBytes(base64);

        String path = fileUtil.saveFile(bytes, fileName, appid);
        res.put("url", path);

        return ResponseBean.success(res);
    }


}
